#!/usr/bin/env python3

from os import environ
from os.path import join, abspath, dirname
from codecs import open
from setuptools import setup, find_packages
from subprocess import check_output


def long_description():
    with open('README.md', 'r') as fh:
        return fh.read()


def version():
    with open(join(abspath(dirname(__file__)), 'desec_dns_api/__init__.py')) as fh:
        for line in fh:
            if line.startswith('__version__'):
                ver = line.split("'")[1]
                if environ.get('CI_COMMIT_SHA', '') != '' and environ.get('CI_COMMIT_TAG', '') == '':
                    # attach commit hash to non tagged test uploads from CI
                    commits = check_output(['/usr/bin/env', 'git', 'rev-list', '--count', 'HEAD'], text=True)
                    return f'{ ver }.dev{ commits.strip() }'
                return ver

    raise RuntimeError('Unable to find version string.')


setup(
    name='desec_dns_api',
    version=version(),
    author='Ricardo Band',
    author_email='email@ricardo.band',
    description='Wrapper for desec DNS API',
    long_description=long_description(),
    long_description_content_type='text/markdown',
    url='https://gitlab.com/XenGi/desec-dns-api',
    project_urls={
        # 'Documentation': 'https://packaging.python.org/tutorials/distributing-packages/',
        # 'Funding': 'https://donate.pypi.org',
        # 'Say Thanks!': 'http://saythanks.io/to/example',
        'Source': 'https://gitlab.com/XenGi/desec-dns-api',
        'Tracker': 'https://gitlab.com/XenGi/desec-dns-api/issues',
    },
    packages=find_packages(exclude=['tests']),
    install_requires=[
        'requests',
    ],
    classifiers=[
        'Development Status :: 1 - Planning',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
        'Topic :: Internet :: Name Service (DNS)',
        'Topic :: System',
        'Topic :: System :: Networking',
        'Topic :: System :: Systems Administration',
        'Topic :: Utilities',
        'Typing :: Typed',
    ],
    keywords='desec dns api',
    python_requires='>=3.6',
)
